"use strict";
const lodashEs = require("lodash-es");
const runtimeCore = require("@vue/runtime-core");
const toCamleObject = (source, target) => {
  if (lodashEs.isNil(source) || lodashEs.isString(source) || lodashEs.isNumber(source) || lodashEs.isRegExp(source) || lodashEs.isDate(source) || lodashEs.isFunction(source)) {
    return source;
  }
  if (lodashEs.isArray(source)) {
    return source.map((v) => toCamleObject(v));
  }
  const res = target ?? {};
  for (const prop in source) {
    const val = source[prop];
    if (prop.startsWith("@")) {
      res[prop] = toCamleObject(val);
    } else {
      res[lodashEs.camelCase(prop)] = toCamleObject(val);
    }
  }
  return res;
};
const toSnakeObject = (source, target) => {
  if (lodashEs.isNil(source) || lodashEs.isString(source) || lodashEs.isNumber(source) || lodashEs.isRegExp(source) || lodashEs.isDate(source) || lodashEs.isFunction(source)) {
    return source;
  }
  if (lodashEs.isArray(source)) {
    return source.map((v) => toSnakeObject(v));
  }
  const res = target ?? {};
  for (const prop in source) {
    const val = source[prop];
    if (prop.startsWith("@")) {
      res[prop] = toSnakeObject(val);
    } else {
      res[lodashEs.snakeCase(prop)] = toSnakeObject(val);
    }
  }
  return res;
};
const asArray = (v) => {
  if (lodashEs.isNil(v)) {
    return [];
  }
  if (lodashEs.isArray(v)) {
    return v;
  }
  return [v];
};
const awaitGet = (v, ...restArgs) => {
  if (lodashEs.isFunction(v)) {
    const fun = v;
    v = fun(...restArgs);
  }
  if (isPromise(v)) {
    return Promise.all([v])[0];
  } else {
    return v;
  }
};
const isPromise = (val) => {
  return lodashEs.isObject(val) && lodashEs.isFunction(val["then"]) && lodashEs.isFunction(val["catch"]);
};
let id = 1;
const useID = (prefix) => {
  return (prefix ?? "") + ++id;
};
const MessageSymbol = Symbol();
let msg;
function useMessage(msgType) {
  const _msg = runtimeCore.inject(MessageSymbol, msg);
  if (lodashEs.isNil(_msg)) {
    throw new Error("Please use `setupMessage()` or `provide(MessageSymbol, v)` first before call `useMessage()`");
  }
  if (!lodashEs.isNil(msgType)) {
    return _msg[msgType];
  }
  return _msg;
}
const setupMessage = (_msg) => {
  msg = _msg;
};
exports.MessageSymbol = MessageSymbol;
exports.asArray = asArray;
exports.awaitGet = awaitGet;
exports.isPromise = isPromise;
exports.setupMessage = setupMessage;
exports.toCamleObject = toCamleObject;
exports.toSnakeObject = toSnakeObject;
exports.useID = useID;
exports.useMessage = useMessage;
